Index: main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/browser_templates/mydatadropdowntabs.pt
===================================================================
--- main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/browser_templates/mydatadropdowntabs.pt	(revision 7450)
+++ main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/browser_templates/mydatadropdowntabs.pt	(revision 7450)
@@ -0,0 +1,9 @@
+<li tal:attributes="class viewlet/active" data-dropdown="dropdown" >
+  <a href="#" class="dropdown-toggle" tal:content="viewlet/tab_title">Tab Title</a>
+  <ul class="dropdown-menu">
+    <li tal:repeat="target viewlet/targets">
+      <a tal:attributes="href target/url"
+         tal:content="target/title">Link Title</a>
+    </li>
+  </ul>
+</li>
Index: main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/browser_templates/studycoursepage.pt
===================================================================
--- main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/browser_templates/studycoursepage.pt	(revision 7449)
+++ main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/browser_templates/studycoursepage.pt	(revision 7450)
@@ -55,5 +55,5 @@
 
 
-<table class="zebra">
+<table>
   <thead>
     <tr>
@@ -63,5 +63,5 @@
   </thead>
   <tbody>
-    <tr tal:repeat="value context/values">
+    <tr class="gradeC" tal:repeat="value context/values">
       <td> <a tal:attributes="href value/__name__">
       <span tal:content="value/level">CODE</span></a></td>
Index: main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/viewlets.py
===================================================================
--- main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/viewlets.py	(revision 7449)
+++ main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/students/viewlets.py	(revision 7450)
@@ -60,11 +60,6 @@
                 url, self.text)
 
-class StudentManageBaseLink(StudentManageLink):
-    grok.order(1)
-    link = 'index'
-    text = u'Base Data'
-
 class StudentManageApplicationLink(StudentManageLink):
-    grok.order(2)
+    grok.order(1)
     link = 'application_slip'
     text = u'Application Slip'
@@ -75,7 +70,12 @@
         if slip:
             url = self.view.url(self.context,self.link)
-            return u'<li"><a href="%s">%s</a></li>' % (
+            return u'<li><a href="%s">%s</a></li>' % (
                     url, self.text)
         return ''
+
+class StudentManageBaseLink(StudentManageLink):
+    grok.order(2)
+    link = 'index'
+    text = u'Base Data'
 
 class StudentManageClearanceLink(StudentManageLink):
@@ -111,77 +111,4 @@
     text = u'History'
 
-
-class StudentMenu(grok.ViewletManager):
-    grok.name('top_student')
-
-class StudentLink(PlainActionButton):
-    """A link displayed in the student box which shows up for StudentNavigation
-    objects.
-
-    """
-    grok.baseclass()
-    grok.viewletmanager(StudentMenu)
-    grok.context(ISIRPObject)
-    grok.view(Interface)
-    grok.order(5)
-    grok.require('waeup.viewStudent')
-
-    link = 'index'
-    text = u'Base Data'
-
-    @property
-    def target_url(self):
-        """Get a URL to the target...
-        """
-        return self.view.url(self.context.getStudent(), self.link)
-
-class StudentBaseLink(StudentLink):
-    grok.order(1)
-    link = 'index'
-    text = u'Base Data'
-
-class ApplicationSlipLink(StudentLink):
-    grok.order(2)
-    link = 'application_slip'
-    text = u'Application Slip'
-
-    @property
-    def target_url(self):
-        slip = getUtility(IExtFileStore).getFileByContext(
-            self.context.getStudent(), attr=self.link)
-        if slip:
-            return self.view.url(self.context,self.link)
-        return
-
-class StudentClearanceLink(StudentLink):
-    grok.order(3)
-    link = 'view_clearance'
-    text = u'Clearance Data'
-
-class StudentPersonalLink(StudentLink):
-    grok.order(4)
-    link = 'view_personal'
-    text = u'Personal Data'
-
-class StudentStudyCourseLink(StudentLink):
-    grok.order(5)
-    link = 'studycourse'
-    text = u'Study Course'
-
-class StudentPaymentsLink(StudentLink):
-    grok.order(6)
-    link = 'payments'
-    text = u'Payments'
-
-class StudentAccommodationLink(StudentLink):
-    grok.order(7)
-    link = 'accommodation'
-    text = u'Accommodation'
-
-class StudentHistoryLink(StudentLink):
-    grok.order(8)
-    link = 'history'
-    text = u'History'
-
 class StudentsTab(PrimaryNavTab):
     """Students tab in primary navigation.
@@ -227,15 +154,38 @@
 
 class MyStudentDataTab(PrimaryStudentNavTab):
     """MyData-tab in primary navigation.
     """
     grok.order(3)
     grok.require('waeup.viewMyStudentDataTab')
+    grok.template('mydatadropdowntabs')
     pnav = 4
     tab_title = u'My Data'
 
     @property
-    def link_target(self):
-        rel_link = '/students/%s' % self.request.principal.id
-        return self.view.application_url() + rel_link
+    def active(self):
+        view_pnav = getattr(self.view, 'pnav', 0)
+        if view_pnav == self.pnav:
+            return 'active dropdown'
+        return 'dropdown'
+
+    @property
+    def targets(self):
+        student_url = self.view.application_url() + (
+            '/students/%s' % self.request.principal.id)
+        #app_slip = getUtility(IExtFileStore).getFileByContext(
+        #    self.context.getStudent(), 'application_slip')
+        targets = []
+        #if app_slip:
+        #    targets = [{'url':student_url + '/application_slip', 'title':'Application Slip'},]
+        targets += [
+            {'url':student_url + '/index', 'title':'Base Data'},
+            {'url':student_url + '/view_clearance', 'title':'Clearance Data'},
+            {'url':student_url + '/view_personal', 'title':'Personal Data'},
+            {'url':student_url + '/studycourse', 'title':'Study Course'},
+            {'url':student_url + '/payments', 'title':'Payments'},
+            {'url':student_url + '/accommodation', 'title':'Accommodation Data'},
+            {'url':student_url + '/history', 'title':'History'},
+            ]
+        return targets
 
 def handle_file_delete(context, view, download_name):
@@ -227,15 +154,38 @@
 
 class MyStudentDataTab(PrimaryStudentNavTab):
-    """MyData-tab in primary navigation.
+    """MyData dropdown tab in primary navigation.
     """
     grok.order(3)
